@@ -17,11 +17,13 @@
 #include "settings.h"
 
 #include <QDateTime>
+#include <QDir>
 #include <QList>
 #include <QThread>
 
 #include <kio/global.h>
-#include <KStandardDirs>
+#include <QStandardPaths>
+
 
 TransferHistoryItem::TransferHistoryItem() : QObject()
 {}
@@ -127,16 +129,20 @@ QList <TransferHistoryItem> TransferHistoryStore::items() const
 
 TransferHistoryStore *TransferHistoryStore::getStore()
 {
+    // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
+    if (!QFileInfo::exists(QStandardPaths::writableLocation(QStandardPaths::DataLocation))) {
+        QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
+    }
     switch(Settings::historyBackend())
     {
         case TransferHistoryStore::SQLite:
 #ifdef HAVE_SQLITE
-            return new SQLiteStore(KStandardDirs::locateLocal("appdata", "transferhistory.db"));
+            return new SQLiteStore(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/transferhistory.db"));
             break;
 #endif
         case TransferHistoryStore::Xml:
         default:
-            return new XmlStore(KStandardDirs::locateLocal("appdata", "transferhistory.kgt"));
+            return new XmlStore(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/transferhistory.kgt"));
     }
 }
 
